@@ -5,6 +5,15 @@
 /* where is jbterm.conf in */
 #undef SYSCONFDIR
 
+/* Support 1bpp */
+#undef JFB_1BPP
+
+/* Support 2bpp */
+#undef JFB_2BPP
+
+/* Support 4bpp */
+#undef JFB_4BPP
+
 /* Support 8bpp */
 #undef JFB_8BPP
 
@@ -47,3 +56,8 @@
 /* Color gamma effect */
 #undef JFB_COLOR_GAMMA
 
+/* Supprt Dimmer (Screen blank) */
+#undef JFB_ENABLE_DIMMER
+
+/* Support reverse video */
+#undef JFB_REVERSEVIDEO
