@@ -41,17 +41,19 @@
 #include <sys/ioctl.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
+#ifdef JFB_VGA16FB
 #include <sys/io.h>
+#endif
 #include <linux/vt.h>
 #include <linux/fb.h>
 #include <asm/page.h>
 
-#include <mytypes.h>
-#include <fbcommon.h>
-#include <message.h>
-#include <util.h>
+#include "mytypes.h"
+#include "fbcommon.h"
+#include "message.h"
+#include "util.h"
 
-#include <fbdpsp.h>
+#include "fbdpsp.h"
 
 static int tfbm_select_visual(  TFrameBufferMemory* p,
 				struct fb_var_screeninfo* fbvs,
@@ -273,12 +275,13 @@ int tfbm_set_blank(int fh, int blank)
 {
       int fd;
       struct vt_stat vstat;
-      if (-1 == (fd = open("/dev/tty0", O_RDWR, 0))) {
+      if (-1 == (fd = util_privilege_open("/dev/tty0", O_RDWR, 0))) {
               die("open /dev/tty0: %s\n", strerror(errno));
       }
       if (-1 == ioctl(fd, VT_GETSTATE, &vstat)) {
               die("ioctl VT_GETSTATE");
       }
+      close(fd);
       if (vstat.v_active != gFramebuffer.my_vt)
               return(0);         /* Not foreground console */
 
@@ -447,15 +450,16 @@ void tfbm_init(TFrameBufferMemory* p)
 	if((fbdn = (char*)malloc(16)) == NULL) {
 		die("malloc: %s\n", strerror(errno));
 	}
+	memset(fbdn, 0, 16);
 
 	if (NULL != (env_fbdn = getenv("FRAMEBUFFER"))) {
-		strncpy(fbdn, env_fbdn, 16);
+		strncpy(fbdn, env_fbdn, 15);
 	} else {
 		int fd;
 		struct fb_con2fbmap c2m;
 		struct vt_stat vstat;
 
-		if (-1 == (fd = open("/dev/tty0", O_RDWR, 0))) {
+		if (-1 == (fd = util_privilege_open("/dev/tty0", O_RDWR))) {
 			util_free(fbdn);
 			die("open /dev/tty0: %s\n", strerror(errno));
 		}
@@ -469,7 +473,7 @@ void tfbm_init(TFrameBufferMemory* p)
 #else
 		c2m.console = vstat.v_active;
 #endif
-		if (-1 == (fd = open("/dev/fb0", O_RDWR,0))) {
+		if (-1 == (fd = util_privilege_open("/dev/fb0", O_RDWR))) {
 			util_free(fbdn);
 			die("open /dev/fb0: %s\n", strerror(errno));
 		}
@@ -478,7 +482,7 @@ void tfbm_init(TFrameBufferMemory* p)
 			c2m.framebuffer = 0;
 		}
 		close(fd);
-		snprintf(fbdn, 16, "/dev/fb%d", c2m.framebuffer);
+		snprintf(fbdn, 15, "/dev/fb%d", c2m.framebuffer);
 	}
 }
 
@@ -488,7 +492,7 @@ void tfbm_open(TFrameBufferMemory* p)
 	struct fb_var_screeninfo fb_var;
 	struct fb_fix_screeninfo fb_fix;
 
-	if ((p->fh = open(fbdn, O_RDWR)) == -1) {
+	if ((p->fh = util_privilege_open(fbdn, O_RDWR)) == -1) {
 		die("open %s: %s\n", fbdn, strerror(errno));
 	}
 
