@@ -30,14 +30,14 @@
 #include <sys/types.h>
 #include <string.h>
 
-#include <config.h>
+#include "config.h"
 
-#include <font.h>
-#include <pcf.h>
-#include <util.h>
-#include <message.h>
-#include <csv.h>
-#include <picofont.h>
+#include "font.h"
+#include "pcf.h"
+#include "util.h"
+#include "message.h"
+#include "csv.h"
+#include "picofont.h"
 
 u_int gFontsWidth = 0;
 u_int gFontsHeight = 0;
