@@ -30,7 +30,7 @@
 
 #include <sys/types.h>
 
-#include <getcap.h>
+#include "getcap.h"
 
 #define TAPP_ERR_FLDD	1		/* ΥեȥåȤѤ */
 
