@@ -44,16 +44,16 @@
 #include <getopt.h>
 
 
-#include <pcf.h>
-#include <font.h>
-#include <fbcommon.h>
-#include <term.h>
-#include <vterm.h>
-#include <message.h>
-#include <mytypes.h>
-#include <getcap.h>
-#include <util.h>
-#include <main.h>
+#include "pcf.h"
+#include "font.h"
+#include "fbcommon.h"
+#include "term.h"
+#include "vterm.h"
+#include "message.h"
+#include "mytypes.h"
+#include "getcap.h"
+#include "util.h"
+#include "main.h"
 
 
 #ifdef SYSCONFDIR
@@ -110,8 +110,9 @@ void tapp_change_to_original_console(TApplication* p)
         signal(SIGUSR2, SIG_DFL);
 */
 
-        cfd = open("/dev/console", O_WRONLY);
-        if (cfd < 0 && (cfd = open("/dev/console", O_RDONLY)) < 0) {
+        cfd = util_privilege_open("/dev/console", O_WRONLY);
+        if (cfd < 0 && 
+	    (cfd = util_privilege_open("/dev/console", O_RDONLY)) < 0) {
                 print_strerror("/dev/console");
         }
         if (ioctl(cfd, VT_ACTIVATE, n) != 0) {
@@ -171,8 +172,9 @@ void tapp_change_to_new_console(TApplication* p)
         char vtty[128];
         int mode;
 
-        cfd = open("/dev/console", O_WRONLY);
-        if (cfd < 0 && (cfd = open("/dev/console", O_RDONLY)) < 0) {
+        cfd = util_privilege_open("/dev/console", O_WRONLY);
+        if (cfd < 0 && 
+	    (cfd = util_privilege_open("/dev/console", O_RDONLY)) < 0) {
                 die("can't open /dev/console");
         }
 #if 1
@@ -201,7 +203,7 @@ void tapp_change_to_new_console(TApplication* p)
         }
         setsid();
         sprintf(vtty, "/dev/tty%d", vtNum);
-        if ((vfd = open(vtty, O_RDWR)) < 0) {
+        if ((vfd = util_privilege_open(vtty, O_RDWR)) < 0) {
                 die("can't open %s", vtty);
         }
         if (ioctl(cfd, VT_ACTIVATE, vtNum) != 0) {
@@ -218,7 +220,7 @@ void tapp_change_to_new_console(TApplication* p)
 
 void ShowCaps(void)
 {
-	fprintf(stderr,
+	fprintf(stdout,
 		"======== Capabilities =====================================\n"
 		"[[ COLOR ]]\n"
 #ifdef JFB_VGA16FB
@@ -264,10 +266,10 @@ void ShowCaps(void)
 #endif
 		"\n"
 	);
-	fprintf(stderr, "[[ FONTSET ]]\n");
-	tfont_ary_show_list(stderr);
+	fprintf(stdout, "[[ FONTSET ]]\n");
+	tfont_ary_show_list(stdout);
 
-	fprintf(stderr,
+	fprintf(stdout,
 		"[[ ENCODING ]]\n"
 #ifdef JFB_MINI_JFBTERM
 			" ISO-2022-JP EUC-JP"
@@ -300,8 +302,11 @@ int main(int argc, char *argv[])
 	const char* tn;
 	const char* en;
 
+	util_privilege_init();
+
 	fprintf(stderr,
 		"%s - Kanji on framebuffer console Version %s\n"
+		"       Copyright (C) 2003 Fumitoshi UKAI\n"
 		"	Copyright (C) 1999-2000 Noritoshi Masuichi\n"
 		"This program is based on KON2\n"
 		"	Copyright (C) 1992-1996 Takashi MANABE\n\n",
@@ -317,11 +322,6 @@ int main(int argc, char *argv[])
 		exit(EXIT_SUCCESS);
 	}
 
-	if (geteuid() != 0) {
-		fprintf(stderr, "permission denied.\n");
-		exit(EXIT_FAILURE);
-	}
-
 	tcaps_read(&(gApp.gCaps), FILE_JFBTERM_CONF);
 	fcap = tcaps_find(&(gApp.gCaps), "fontset"); 
 	if (!fcap || !(fcap->values)) {
@@ -329,7 +329,7 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	if ((cp = tcaps_find_first(&(gApp.gCaps), "gamma")) != NULL) {
+	if ((cp = tcaps_find_first(&(gApp.gCaps), "color.gamma")) != NULL) {
 		fbgamma = (float)atof(cp);
 	}
 
@@ -343,7 +343,7 @@ int main(int argc, char *argv[])
 
 	tn = tcaps_find_first(&(gApp.gCaps), "term");
 	if (!tn) {
-		tn = "kon";
+		tn = "jfbterm";
 	}
 	en = tcaps_find_first(&(gApp.gCaps), "encoding");
 	if (!en) {
@@ -356,5 +356,3 @@ int main(int argc, char *argv[])
 
 	exit(EXIT_SUCCESS);
 }
-
-	
