@@ -43,12 +43,13 @@
 #include <utmp.h>
 #include <grp.h>
 
-#include <term.h>
-#include <vterm.h>
-#include <fbcommon.h>
-#include <font.h>
-#include <message.h>
-#include <main.h>
+#include "term.h"
+#include "vterm.h"
+#include "fbcommon.h"
+#include "font.h"
+#include "message.h"
+#include "main.h"
+#include "util.h"
 
 #include "config.h"
 
@@ -246,6 +247,7 @@ void tterm_wakeup_shell_as_child(TTerm* p, const char* tn)
 		signal(SIGCHLD, sigchld);
 		return;
 	}
+	util_privilege_drop();
 
 	setenv("TERM", tn, 1);
 
@@ -279,11 +281,12 @@ void	tterm_set_utmp(TTerm* p)
 	struct group	*ttygrp;
 	char	*tn;
 
-	pw = getpwuid(getuid());
+	pw = getpwuid(util_getuid());
 	tn = rindex(p->name, '/') + 1;
 	memset((char *)&utmp, 0, sizeof(utmp));
 	strncpy(utmp.ut_id, tn + 3, sizeof(utmp.ut_id));
 	utmp.ut_type = DEAD_PROCESS;
+	util_privilege_on();
 	setutent();
 	getutid(&utmp);
 	utmp.ut_type = USER_PROCESS;
@@ -300,7 +303,8 @@ void	tterm_set_utmp(TTerm* p)
 		p->ttygid = -1;
 	}
 	chmod(p->name, 0720);
-	chown(p->name, getuid(), p->ttygid);
+	chown(p->name, util_getuid(), p->ttygid);
+	util_privilege_off();
 }
 
 void	tterm_reset_utmp(TTerm* p)
@@ -312,6 +316,7 @@ void	tterm_reset_utmp(TTerm* p)
 	memset((char *)&utmp, 0, sizeof(utmp));
 	strncpy(utmp.ut_id, tn, sizeof(utmp.ut_id));
 	utmp.ut_type = USER_PROCESS;
+	util_privilege_on();
 	setutent();
 	utp = getutid(&utmp);
 	utp->ut_type = DEAD_PROCESS;
@@ -322,6 +327,7 @@ void	tterm_reset_utmp(TTerm* p)
 	endutent();
 	chmod(p->name, 0666);
 	chown(p->name, 0, p->ttygid);
+	util_privilege_off();
 	p->ttygid = FALSE;
 }
 
