@@ -37,14 +37,14 @@
 #include	<sys/ioctl.h>
 #include	<sys/kd.h>
 
-#include	<util.h>
-#include	<term.h>
-#include	<vterm.h>
-#include	<font.h>
-#include	<csv.h>
+#include	"util.h"
+#include	"term.h"
+#include	"vterm.h"
+#include	"font.h"
+#include	"csv.h"
 
-#include	<sequence.h>
-#include	<message.h>
+#include	"sequence.h"
+#include	"message.h"
 
 #define	LEN_REPORT	9
 
@@ -259,7 +259,7 @@ static inline int IS_GL_AREA(TVterm* p, u_char ch)
 }
 static inline int IS_GR_AREA(TVterm* p, u_char ch)
 {
-	return (p->tgl.type & TFONT_FT_96CHAR) ? (0x9F < ch) :
+	return (p->tgr.type & TFONT_FT_96CHAR) ? (0x9F < ch) :
 						(0xA0 < ch && ch < 0xFF);
 }
 
@@ -323,8 +323,8 @@ static int tvterm_put_normal_char(TVterm* p, u_char ch, const char *buff)
 			p->knj1idx = p->tgr.idx;
 		} else {
 			INSERT_N_CHARS_IF_NEEDED(p, 1);
-			tvterm_sput(p, p->tgl.idx,
-				p->tgr.half == FH_LEFT ? ch & 0x80: ch);
+			tvterm_sput(p, p->tgr.idx,
+				p->tgr.half == FH_LEFT ? ch & ~0x80: ch);
 			p->pen.x ++;
 			p->tgr = p->gr; p->tgl = p->gl;
 		}
@@ -391,7 +391,17 @@ int tvterm_iso_C0_set(TVterm* p, u_char ch)
 
 int tvterm_iso_C1_set(TVterm* p, u_char ch)
 {
+    switch (ch) {
+    case ISO_SS2:	/* single shift 2 */
+	tvterm_invoke_gx(p, &(p->tgr), 2); /* GR <== G2 */
 	return 1;
+    case ISO_SS3:	/* single shift 3 */
+	tvterm_invoke_gx(p, &(p->tgr), 3); /* GR <== G3 */
+	return 1;
+    default:
+	break;
+    }
+    return 0;
 }
 
 void tvterm_emulate(TVterm* p, const char *buff, int nchars)
@@ -490,6 +500,13 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 			p->pen.y --;
 		}
 		break;
+	case Fe(ISO_SS2):		/* N *//* 7bit single shift 2 */
+		tvterm_invoke_gx(p, &(p->tgl), 2); /* GL <== G2 */
+		break;
+	case Fe(ISO_SS3):		/* O *//* 7bit single shift 3 */
+		tvterm_invoke_gx(p, &(p->tgl), 3); /* GL <== G3 */
+		break;
+
 	case ISO_RIS:			/* c */
 		p->pen.fcol = 7;
 		p->pen.bcol = 0;
@@ -620,7 +637,7 @@ void tvterm_set_window_size(TVterm* p)
 	win.ws_row = p->ymax;
 	win.ws_col = p->xcap;
 	win.ws_xpixel = 0;
-	win.ws_xpixel = 0;
+	win.ws_ypixel = 0;
 	ioctl(p->term->ttyfd, TIOCSWINSZ, &win);
 }
 
