@@ -40,12 +40,12 @@
 #include	<sys/ioctl.h>
 #include	<sys/kd.h>
 
-#include	<util.h>
-#include	<vterm.h>
-#include	<term.h>
-#include	<font.h>
-#include	<fbcommon.h>
-#include	<config.h>
+#include	"util.h"
+#include	"vterm.h"
+#include	"term.h"
+#include	"font.h"
+#include	"fbcommon.h"
+#include	"config.h"
 
 
 #if 0
